@@ -5,6 +5,7 @@ using QCoDeS.
 
 import inspect
 import logging
+import os
 from contextlib import contextmanager
 from functools import partial
 from typing import Any, List, Optional, Sequence, Tuple, Union, cast
@@ -13,6 +14,7 @@ import matplotlib
 import matplotlib.pyplot as plt
 import numpy as np
 from matplotlib.ticker import FuncFormatter
+from typing_extensions import Literal
 
 import qcodes as qc
 from qcodes.dataset.data_set import load_by_run_spec
@@ -99,8 +101,8 @@ def plot_dataset(
     rescale_axes: bool = True,
     auto_color_scale: Optional[bool] = None,
     cutoff_percentile: Optional[Union[Tuple[float, float], float]] = None,
-    complex_plot_type: str = "real_and_imag",
-    complex_plot_phase: str = "radians",
+    complex_plot_type: Literal["real_and_imag", "mag_and_phase"] = "real_and_imag",
+    complex_plot_phase: Literal["radians", "degrees"] = "radians",
     **kwargs: Any,
 ) -> AxesTupleList:
     """
@@ -305,6 +307,46 @@ def plot_dataset(
     return axeslist, new_colorbars
 
 
+def plot_and_save_image(
+    data: DataSetProtocol, save_pdf: bool = True, save_png: bool = True
+) -> Tuple[
+    DataSetProtocol,
+    List[matplotlib.axes.Axes],
+    List[Optional[matplotlib.colorbar.Colorbar]],
+]:
+    """
+    The utility function to plot results and save the figures either in pdf or
+    png or both formats.
+
+    Args:
+        data: The QCoDeS dataset to be plotted.
+        save_pdf: Save figure in pdf format.
+        save_png: Save figure in png format.
+    """
+    from qcodes import config
+
+    dataid = data.captured_run_id
+    axes, cbs = plot_dataset(data)
+    mainfolder = config.user.mainfolder
+    experiment_name = data.exp_name
+    sample_name = data.sample_name
+    storage_dir = os.path.join(mainfolder, experiment_name, sample_name)
+    os.makedirs(storage_dir, exist_ok=True)
+    png_dir = os.path.join(storage_dir, "png")
+    pdf_dif = os.path.join(storage_dir, "pdf")
+    os.makedirs(png_dir, exist_ok=True)
+    os.makedirs(pdf_dif, exist_ok=True)
+    for i, ax in enumerate(axes):
+        if save_pdf:
+            full_path = os.path.join(pdf_dif, f"{dataid}_{i}.pdf")
+            ax.figure.savefig(full_path, dpi=500)
+        if save_png:
+            full_path = os.path.join(png_dir, f"{dataid}_{i}.png")
+            ax.figure.savefig(full_path, dpi=500)
+    res = data, axes, cbs
+    return res
+
+
 def plot_by_id(
     run_id: int,
     axes: Optional[Union[matplotlib.axes.Axes, Sequence[matplotlib.axes.Axes]]] = None,
@@ -314,14 +356,14 @@ def plot_by_id(
     rescale_axes: bool = True,
     auto_color_scale: Optional[bool] = None,
     cutoff_percentile: Optional[Union[Tuple[float, float], float]] = None,
-    complex_plot_type: str = "real_and_imag",
-    complex_plot_phase: str = "radians",
+    complex_plot_type: Literal["real_and_imag", "mag_and_phase"] = "real_and_imag",
+    complex_plot_phase: Literal["radians", "degrees"] = "radians",
     **kwargs: Any,
 ) -> AxesTupleList:
     """
     Construct all plots for a given `run_id`. Here `run_id` is an
     alias for `captured_run_id` for historical reasons. See the docs
-    of :func:`.load_by_run_spec` for details of loading runs.
+    of :func:`qcodes.dataset.load_by_run_spec` for details of loading runs.
     All other arguments are forwarded
     to :func:`.plot_dataset`, see this for more details.
     """
@@ -339,7 +381,9 @@ def plot_by_id(
 
 
 def _complex_to_real_preparser(
-    alldata: Sequence[Sequence[DSPlotData]], conversion: str, degrees: bool = False
+    alldata: Sequence[Sequence[DSPlotData]],
+    conversion: Literal["real_and_imag", "mag_and_phase"],
+    degrees: bool = False,
 ) -> NamedData:
     """
     Convert complex-valued parameters to two real-valued parameters, either
